@@ -12,6 +12,8 @@ import numpy as np
 from numpy.testing import assert_allclose, assert_equal, assert_
 import pandas as pd
 
+import pytest
+
 import patsy
 
 from statsmodels.discrete.discrete_model import Poisson, Logit, Probit
@@ -91,6 +93,10 @@ class CheckGAMMixin(object):
         assert_allclose(res1.fittedvalues, res2.fitted_values,
                         rtol=self.rtol_fitted)
 
+    @pytest.mark.smoke
+    def test_null_smoke(self):
+        self.res1.llnull
+
 
 class TestTheilPLS5(CheckGAMMixin):
 
@@ -120,6 +126,9 @@ class TestTheilPLS5(CheckGAMMixin):
         assert_allclose(np.asarray(res1.cov_params()),
                         res2.Ve * self.covp_corrfact, rtol=1e-4)
 
+    def test_null_smoke(self):
+        pytest.skip("llnull not available")
+
 
 class TestGLMPenalizedPLS5(CheckGAMMixin):
 
@@ -129,7 +138,7 @@ class TestGLMPenalizedPLS5(CheckGAMMixin):
     def setup_class(cls):
         exog, penalty_matrix, restriction = cls._init()
         endog = data_mcycle['accel']
-        pen = smpen.L2ContraintsPenalty(restriction=restriction)
+        pen = smpen.L2ConstraintsPenalty(restriction=restriction)
         mod = GLMPenalized(endog, exog, family=family.Gaussian(),
                            penal=pen)
         # scaling of penweight in R mgcv
@@ -585,7 +594,8 @@ class TestGAMMPGBSPoisson(CheckGAMMixin):
 
         # linpred = res1.predict(self.exog[2:4], res1.model.smoother.x[2:4],
         #                        linear=True)
-        linpred = res1.predict(df_autos.iloc[2:4], res1.model.smoother.x[2:4],
+        xp = pd.DataFrame(res1.model.smoother.x[2:4])
+        linpred = res1.predict(df_autos.iloc[2:4], xp,
                                linear=True)
         assert_allclose(linpred, res2.linear_predictors[2:4],
                         rtol=self.rtol_fitted)
@@ -598,7 +608,8 @@ class TestGAMMPGBSPoisson(CheckGAMMixin):
         res2 = self.res2
         wtt = res1.wald_test_terms(skip_single=True,
                                    combine_terms=['fuel', 'drive',
-                                                  'weight', 'hp'])
+                                                  'weight', 'hp'],
+                                   scalar=True)
         # mgcv has term test for linear part
         assert_allclose(wtt.statistic[:2], res2.pTerms_chi_sq, rtol=1e-7)
         assert_allclose(wtt.pvalues[:2], res2.pTerms_pv, rtol=1e-6)
